from distutils.core import setup

setup(
    name='pymysqlpool',
    version='0.1',
    packages=['pymysqlpool'],
    url='',
    license='MIT',
    author='Christopher Lee',
    author_email='',
    requires=['pymysql', 'pandas'],
    description='MySQL connection pool utility.'
)



# -*- coding: utf-8 -*-
from application.First_app.first_app import First_app

first_app = First_app()

url_list = [
    ['GET', '/request_info', first_app.request_info],
    ['GET', '/post_info', first_app.post_info],
]



# -*- coding: utf-8 -*-
# @Author: yuanshaohang
# @Date: 2023-02-17- 17:20:53
# @Version: 1.0.0
# @Description: 动态mysql查询工具类
import re
import time
from web_tools.tools import Tools_user

import pymysql
from pymysqlpool import ConnectionPool

Mysql = {
    'MYSQL_HOST': 'aliyun-rds-qdb.bl-ai.com',
    'MYSQL_DBNAME': 'spider_frame',
    'MYSQL_USER': 'yuanshaohang',
    'MYSQL_PASSWORD': 'yhHoRatHtG8',
    'PORT': 3306
}


class MysqlDB:
    def __init__(self):
        self.host = Mysql['MYSQL_HOST']
        self.port = Mysql['PORT']
        self.user = Mysql['MYSQL_USER']
        self.password = Mysql['MYSQL_PASSWORD']
        self.db = Mysql['MYSQL_DBNAME']
        # self.conn = None
        self.pool = self.create_pool()
        self.condition_re = re.compile('(.*?)\\(')
        self.params_re = re.compile('\\((.*?)\\)')

    def deal_re(self, demo, defult=None):  # 判断正则是否匹配到的是否为空
        if demo != None:
            data_tuple = demo.groups()
            lists = list(data_tuple)
            data = ''.join([i for i in lists if i != None])
            return data
        else:
            if defult:
                return defult
            return ''

    def create_pool(self):
        conn = ConnectionPool(
            pool_name='mypool',
            host=self.host,
            port=self.port,
            user=self.user,
            password=self.password,
            db=self.db,
            autocommit=True
        )
        return conn

    def execute(self, query, parameters=None, many=False):
        attempts = 3  # allow 3 attempts to execute the query
        while attempts > 0:
            conn = self.pool.borrow_connection()
            try:
                with conn.cursor() as cursor:
                    if many:
                        cursor.executemany(query, parameters)
                    else:
                        cursor.execute(query, parameters)
                    conn.commit()
                    if cursor.lastrowid:
                        return cursor.lastrowid
                    else:
                        return cursor.rowcount
            except pymysql.OperationalError as e:
                if e.args[0] in (2006, 2013):  # MySQL server has gone away
                    self.pool.close()
                    self.pool = self.create_pool()
                    attempts -= 1
                else:
                    raise
            except Exception as e:
                print(f"Error while executing query: {e}")
                conn.rollback()
                attempts -= 1
                if attempts == 0:
                    raise Exception("Failed to execute query after 3 attempts")
            finally:
                if conn:
                    conn.close()

    def insert(self, table, data):
        columns = ', '.join([f"`{i}`" for i in data.keys()])
        placeholders = ', '.join(['%s'] * len(data))
        query = f"INSERT IGNORE INTO `{table}` ({columns}) VALUES ({placeholders});"

        update = ', '.join([f"`{key}` = %s" for key in data.keys()])
        sql = f"INSERT INTO {table} ({columns}) VALUES ({placeholders}) ON DUPLICATE KEY UPDATE {update}"
        print(sql % tuple([f"'{i}'" if i else i for i in data.values()]*2))

        print(query % tuple([f"'{i}'" if i else i for i in data.values()]))
        return self.execute(query, tuple(data.values()))

    def update(self, table, set_data, where=None):
        set_pairs = [f"`{column}`=%s" for column in set_data.keys()]
        query = f"UPDATE `{table}` SET {', '.join(set_pairs)}"
        parameters = tuple(set_data.values())
        if where:
            query += f" WHERE {where};"
        print(query % tuple([f"'{i}'" if i else i for i in parameters]))
        return self.execute(query, parameters)

    def delete(self, table, where=None):
        query = f"DELETE FROM `{table}`"
        if where:
            query += f" WHERE {where};"
        print(query)
        return self.execute(query)

    def get_condition(self, columns):
        condition_map = {'count': 'count', 'max': 'max', 'distinct': 'distinct'}
        condition = ''
        if isinstance(columns, list):
            columns = ', '.join([f"`{i}`" for i in columns])
        elif isinstance(columns, str):
            condition = self.deal_re(self.condition_re.search(columns))
            condition_exis = True if [True for i in condition_map.keys() if i.upper() in columns.upper()] else False
            if not condition_exis:
                columns = ', '.join(f'`{i.strip(" ")}`' for i in columns.split(','))
        return condition_map, condition, columns

    def select(self, table, columns='*', where=None, order_by=None, limit=None, offset=None):
        condition_map, condition, columns = self.get_condition(columns)
        query = f"SELECT {columns} FROM `{table}`"
        if where:
            query += f" WHERE {where}"
        if order_by:
            query += f" ORDER BY {order_by}"
        if limit:
            query += f" LIMIT {limit}"
        if offset:
            query += f" OFFSET {offset}"
        print(query)
        with self.pool.cursor() as cursor:
            cursor.execute(query)
            data = cursor.fetchall()
            if self.judge_er(condition):
                condition_map = [i.upper() for i in condition_map.keys()]
            if f'{condition}' in condition_map:
                data = data[0].get(columns)
            return data

    def judge_er(self, str_data):
        if str_data.isupper():
            return True
        else:
            return False


if __name__ == '__main__':
    my_db = MysqlDB()
    # for i in range(10):
    my_db.insert(table='db_base_test', data={'name': 'yuanshaohang', 'age': None, 'sex': '男'})  # 增

    # my_db.update(table='db_base_test', set_data={'name': '袁少航', 'age': 20, 'sex': '男'}, where="`name`='yuanshaohang'")  # 改
    #
    # my_db.delete(table='db_base_test', where="name='袁少航'")  # 删
    #
    # data_list = my_db.select(table='db_base_test', columns='name', where='`name` = "袁少航"')  # 查
    # print(data_list)


# -*- coding: utf-8 -*-
# @Author: yuanshaohang
# @Date: 2023-03-22- 14:13:39
# @Version: 1.0.0
# @Description: TODO
from connecter import RedisDb
import logging
from aiohttp import web
from functools import wraps
from authlib.jose import jwt
from authlib.jose.errors import ExpiredTokenError


class LoginAuth(RedisDb):
    def __init__(self):
        super().__init__()
        self.logger = logging.getLogger(__name__)

    # 登录注册装饰器
    def auth_required(self, func):
        @wraps(func)
        async def wrapped(request, *args, **kwargs):
            if not request.headers.get('Authorization'):
                self.logger.info('用户未登录')
                return web.json_response({'code': 401, 'message': '用户未登录'})
            else:
                Authorization = request.headers.get('Authorization')
                try:
                    user_info = jwt.decode(Authorization, 'yuanshaohang')
                    user_info.validate()
                    if self.r.get(user_info.get('username')):
                        return await func(request, *args, **kwargs)
                    else:
                        return web.json_response({'code': 401, 'message': '登录失效'})
                except ExpiredTokenError:
                    return web.json_response({'code': 401, 'message': '登录失效'})

        return wrapped



# -*-coding: utf-8-*-
# Author : Christopher Lee
# License: MIT License
# File   : pool.py
# Date   : 2017-06-15 14-09
# Version: 0.1
# Description: connection pool manager.

import logging
import threading
import contextlib

from pymysql.connections import Connection
from pymysql.cursors import DictCursor, Cursor

from .pool import PoolContainer, PoolIsFullException, PoolIsEmptyException

__version__ = '0.1'
__author__ = 'Chris'

logger = logging.getLogger('pymysqlpool')

__all__ = ['MySQLConnectionPool']


class NoFreeConnectionFoundError(Exception):
    pass


class PoolBoundaryExceedsError(Exception):
    pass


class MySQLConnectionPool(object):
    """
    A connection pool manager.
    """

    def __init__(self, pool_name, host=None, user=None, password="", database=None, port=3306,
                 charset='utf8', use_dict_cursor=True, max_pool_size=16,
                 enable_auto_resize=True, auto_resize_scale=1.5,
                 pool_resize_boundary=48,
                 defer_connect_pool=False, **kwargs):

        """
        Initialize the connection pool.

        Update: 2017.06.19
            1. remove `step_size` argument
            2. remove `wait_timeout` argument

        :param pool_name: a unique pool_name for this connection pool.
        :param host: host to your database server
        :param user: username to your database server
        :param password: password to access the database server
        :param database: select a default database(optional)
        :param port: port of your database server
        :param charset: default charset is 'utf8'
        :param use_dict_cursor: whether to use a dict cursor instead of a default one
        :param max_pool_size: maximum connection pool size (max pool size can be changed dynamically)
        :param enable_auto_resize: if set to True, the max_pool_size will be changed dynamically
        :param pool_resize_boundary: !!this is related to the max connections of your mysql server!!
        :param auto_resize_scale: `max_pool_size * auto_resize_scale` is the new max_pool_size.
                                The max_pool_size will be changed dynamically only if `enable_auto_resize` is True.
        :param defer_connect_pool: don't connect to pool on construction, wait for explicit call. Default is False.
        :param kwargs: other keyword arguments to be passed to `pymysql.Connection`
        """
        # config for a database connection
        self._host = host
        self._user = user
        self._password = password
        self._database = database
        self._port = port
        self._charset = charset
        self._cursor_class = DictCursor if use_dict_cursor else Cursor
        self._other_kwargs = kwargs

        # config for the connection pool
        self._pool_name = pool_name
        self._max_pool_size = max_pool_size if max_pool_size < pool_resize_boundary else pool_resize_boundary
        # self._step_size = step_size
        self._enable_auto_resize = enable_auto_resize
        self._pool_resize_boundary = pool_resize_boundary
        if auto_resize_scale < 1:
            raise ValueError(
                "Invalid scale {}, must be bigger than 1".format(auto_resize_scale))

        self._auto_resize_scale = int(round(auto_resize_scale, 0))
        # self.wait_timeout = wait_timeout
        self._pool_container = PoolContainer(self._max_pool_size)

        self.__safe_lock = threading.RLock()
        self.__is_killed = False
        self.__is_connected = False

        if not defer_connect_pool:
            self.connect()

    def __repr__(self):
        return '<MySQLConnectionPool ' \
               'name={!r}, size={!r}>'.format(self.pool_name, self.size)

    def __del__(self):
        self.close()

    def __iter__(self):
        """Iterate each connection item"""
        return iter(self._pool_container)

    @property
    def pool_name(self):
        return self._pool_name

    @property
    def pool_size(self):
        return self._pool_container.pool_size

    @property
    def free_size(self):
        return self._pool_container.free_size

    @property
    def size(self):
        return '<boundary={}, max={}, current={}, free={}>'.format(self._pool_resize_boundary,
                                                                   self._max_pool_size,
                                                                   self.pool_size,
                                                                   self.free_size)

    @contextlib.contextmanager
    def cursor(self, cursor=None):
        """Shortcut to get a cursor object from a free connection.
        It's not that efficient to get cursor object in this way for
        too many times.
        """
        with self.connection(autocommit=True) as conn:
            assert isinstance(conn, Connection)
            cursor = conn.cursor(cursor)

            try:
                yield cursor
            except Exception as err:
                conn.rollback()
                raise err
            finally:
                cursor.close()

    @contextlib.contextmanager
    def connection(self, autocommit=False):
        conn = self.borrow_connection()
        assert isinstance(conn, Connection)
        old_value = conn.get_autocommit()
        conn.autocommit(autocommit)
        try:
            yield conn
        except Exception as err:
            # logger.error(err, exc_info=True)
            raise err
        finally:
            conn.autocommit(old_value)
            self.return_connection(conn)

    def connect(self):
        """Connect to this connection pool
        """
        if self.__is_connected:
            return

        logger.info('[{}] Connect to connection pool'.format(self))

        test_conn = self._create_connection()
        try:
            test_conn.ping()
        except Exception as err:
            raise err
        else:
            with self.__safe_lock:
                self.__is_connected = True

            self._adjust_connection_pool()
        finally:
            test_conn.close()

    def close(self):
        """Close this connection pool"""
        try:
            logger.info('[{}] Close connection pool'.format(self))
        except Exception:
            pass

        with self.__safe_lock:
            if self.__is_killed is True:
                return True

        self._free()

        with self.__safe_lock:
            self.__is_killed = True

    def borrow_connection(self):
        """
        Get a free connection item from current pool. It's a little confused here, but it works as expected now.
        """
        block = False

        while True:
            conn = self._borrow(block)
            if conn is None:
                block = not self._adjust_connection_pool()
            else:
                return conn

    def _borrow(self, block):
        try:
            connection = self._pool_container.get(block, None)
        except PoolIsEmptyException:
            return None
        else:
            # check if the connection is alive or not
            connection.ping(reconnect=True)
            return connection

    def return_connection(self, connection):
        """Return a connection to the pool"""
        return self._pool_container.return_(connection)

    def _adjust_connection_pool(self):
        """
        Adjust the connection pool.
        """
        # Create several new connections
        logger.debug('[{}] Adjust connection pool, '
                     'current size is "{}"'.format(self, self.size))

        if self.pool_size >= self._max_pool_size:
            if self._enable_auto_resize:
                self._adjust_max_pool_size()

        try:
            connection = self._create_connection()
        except Exception as err:
            logger.error(err)
            return False
        else:
            try:
                self._pool_container.add(connection)
            except PoolIsFullException:
                # logger.debug('[{}] Connection pool is full now'.format(self.pool_name))
                return False
            else:
                return True

    def _adjust_max_pool_size(self):
        with self.__safe_lock:
            self._max_pool_size *= self._auto_resize_scale
            if self._max_pool_size > self._pool_resize_boundary:
                self._max_pool_size = self._pool_resize_boundary
            logger.debug('[{}] Max pool size adjusted to {}'.format(self, self._max_pool_size))
            self._pool_container.max_pool_size = self._max_pool_size

    def _free(self):
        """
        Release all the connections in the pool
        """
        for connection in self:
            try:
                connection.close()
            except Exception as err:
                _ = err

    def _create_connection(self):
        """Create a pymysql connection object
        """
        return Connection(host=self._host,
                          user=self._user,
                          password=self._password,
                          database=self._database,
                          port=self._port,
                          charset=self._charset,
                          cursorclass=self._cursor_class,
                          **self._other_kwargs)



# -*- coding: utf-8 -*-
import logging
import socket
from random import choice

log_path = ''

"""
format参数值说明：
%(name)s：   打印Logger的名字
%(levelno)s: 打印日志级别的数值
%(levelname)s: 打印日志级别名称
%(pathname)s: 打印当前执行程序的路径，其实就是sys.argv[0]
%(filename)s: 打印当前执行程序的文件名
%(funcName)s: 打印日志的当前函数
%(lineno)d:  打印日志的当前行号
%(asctime)s: 打印日志的时间
%(thread)d:  打印线程ID
%(threadName)s: 打印线程名称
%(process)d: 打印进程ID
%(message)s: 打印日志信息
"""


class NoParsingFilter(logging.Filter):
    def filter(self, record):
        if record.name.startswith('asyncio_config.manager'):
            return False
        return True


logging.getLogger("root").setLevel(logging.WARNING)
logging.getLogger("pika").setLevel(logging.WARNING)
logging.getLogger("requests").setLevel(logging.WARNING)
logging.getLogger("asyncio").setLevel(logging.WARNING)
logging.getLogger("pdfminer").setLevel(logging.WARNING)
logging.getLogger("root").setLevel(logging.WARNING)
logging.getLogger("kafka").setLevel(logging.WARNING)
logging.getLogger("pymysqlpool").setLevel(logging.WARNING)


class SpiderLog(object):
    def __init__(self):
        # self.logger = logging.getLogger("mainModule.sub")
        self.logger = logging.getLogger(__name__)
        self.logger.propagate = False
        self.logger.addFilter(NoParsingFilter())
        if log_path:
            # print('有')
            logging.basicConfig(level=logging.DEBUG,
                                format="%(asctime)s [%(name)s] %(levelname)s: %(message)s",
                                datefmt="%Y-%m-%d %H:%M:%S",
                                filename=log_path)
            console = logging.StreamHandler()
            formatter = logging.Formatter('%(asctime)s [%(name)s] %(levelname)s: %(message)s',
                                          datefmt="%Y-%m-%d %H:%M:%S")
            console.setFormatter(formatter)
            self.logger.addHandler(console)
        else:
            # print('没有')
            logging.basicConfig(level=logging.DEBUG,
                                format="%(asctime)s [%(name)s] %(levelname)s: %(message)s",
                                datefmt="%Y-%m-%d %H:%M:%S")
            logging.getLogger("root").setLevel(logging.WARNING)

    def func(self):
        self.logger.info("Start print log")
        self.logger.info('这是一个测试')
        self.logger.debug("Do something")
        self.logger.warning("Something maybe fail.")
        # try:
        #     open("sklearn.txt", "rb")
        # except (SystemExit, KeyboardInterrupt):
        #     raise
        # except Exception:
        #     self.logger.error("Faild to open sklearn.txt from logger.error", exc_info=True)
        self.logger.info("Finish")


if __name__ == "__main__":
    spider_log = SpiderLog()
    spider_log.func()



# mysql数据库连接
Mysql = {
    'MYSQL_HOST': 'yours',
    'MYSQL_DBNAME': 'yours',
    'MYSQL_USER': 'yours',
    'MYSQL_PASSWORD': 'yours',
    'PORT': 3306
}
# 连接redis数据库
REDIS_HOST_LISTS = {
    'host': 'yours',
    'port': 63791,
    'password': 'yours'
}

is_auth_required = False  # 是否要开启用户登录验证
login_name = ['login']  # 登录视图方法名，用于给登录视图添加白名单，不验证登录


# -*-coding: utf-8-*-
# Author : Christopher Lee
# License: MIT License
# File   : test_pool.py
# Date   : 2017-06-15 15-05
# Version: 0.1
# Description: description of this file.


import datetime
import logging
import string
import threading
import pandas as pd
import random

from pymysqlpool import ConnectionPool

logging.basicConfig(format='[%(asctime)s][%(name)s][%(module)s.%(lineno)d][%(levelname)s] %(message)s',
                    datefmt='%Y-%m-%d %H:%M:%S',
                    level=logging.ERROR)

config = {
    'pool_name': 'test',
    'host': 'localhost',
    'port': 3306,
    'user': 'root',
    'password': 'chris',
    'database': 'test',
    'pool_resize_boundary': 50,
    'enable_auto_resize': True,
    # 'max_pool_size': 10
}


def conn_pool():
    # pool = MySQLConnectionPool(**config)
    pool = ConnectionPool(**config)
    # pool.connect()
    # print(pool)
    return pool


insert_sql = 'INSERT INTO folder (name, icon_url, create_at) VALUES (%s, %s, %s)'
select_sql = 'SELECT * FROM folder ORDER BY id DESC LIMIT 10'
update_sql = ''
delete_sql = ''
truncate_sql = 'TRUNCATE folder'

name_factory = lambda: ''.join(random.sample(string.ascii_letters, random.randint(2, 10)))


def test_insert_one():
    with conn_pool().connection() as conn:
        name = name_factory()
        result = conn.cursor().execute(insert_sql, ('folder_{}'.format(name),
                                                    'icon_{}.png'.format(name),
                                                    datetime.datetime.now()))
        conn.commit()
        # print(result)
        # _ = result
        # print(cursor.connection)
        # time.sleep(.1)


def test_insert_many():
    with conn_pool().cursor() as cursor:
        folders = []

        for _ in range(10):
            name = name_factory()
            folders.append(('folder_{}'.format(name), 'icon_{}.png'.format(name), datetime.datetime.now()))
        result = cursor.executemany(insert_sql, folders)
        print(result)


def test_query():
    with conn_pool().cursor() as cursor:
        cursor.execute(select_sql)
        for item in sorted(cursor, key=lambda x: x['id']):
            print(item)
            # _ = item


def test_truncate():
    with conn_pool().cursor() as cursor:
        cursor.execute(truncate_sql)


def test_with_multi_threading():
    test_truncate()

    def task(n):
        print('In thread {}'.format(threading.get_ident()))
        for _ in range(n):
            test_insert_one()

    threads = [threading.Thread(target=task, args=(100,)) for _ in range(50)]
    for t in threads:
        t.start()

    for t in threads:
        t.join()

    test_query()


def test_borrow_return_connections():
    for _ in range(100000):
        with conn_pool().connection() as connection:
            _ = connection


def test_single_thread_insert():
    # with ping: 11s
    # without ping 11s
    test_truncate()
    for _ in range(5000):
        test_insert_one()

    test_query()


def test_query_with_pandas():
    import pandas as pd

    with conn_pool().connection() as conn:
        r = pd.read_sql(select_sql, conn)
        print(r)


if __name__ == '__main__':
    import time

    start = time.time()
    # test_insert_many()
    # test_query()
    # test_insert_one()
    # test_query_with_pandas()
    test_with_multi_threading()
    test_single_thread_insert()
    # test_borrow_return_connections()
    print('Time consuming is {}'.format(time.time() - start))



# # -*- coding: utf-8 -*-
# import numpy as np
# import pygsheets
# try:
#     client = pygsheets.authorize(service_file="client_secret.json")
#     # 根据key打开谷歌表格
#     sh = client.open_by_key('1sShMP6Z43N1Ij5j_whN-igjxRjjpsDXI6D_lU8aIbl8')
#     # 根据表名获取表格中的工作表
#     new_table = sh.worksheet_by_title('综合')
#     # # 遍历数据
#     zong_map = {}
#     for row in zong:
#         if row[1]:
#             zong = [row[0], row[5], row[6], row[7]]
#             zong_map[row[1]] = zong
#     data_list = []
#     for r in rengong:
#         data = [r[2], r[3], r[5], r[6]]
#         data_list.append(data)
#     # print(data_list)
#     for k, i in enumerate(data_list):
#         try:
#             # new_table.update_values(crange=f'A{k+1}:F{k+1}', values=np.array([i+zong_map[i[0]]]).tolist())
#             print('  '.join((i+zong_map[i[0]])))
#         except KeyError:
#             print('  '.join((i)))
# except Exception as e:
#     import traceback
#     traceback.print_exc()



import re
import json
import time
import aiohttp
import asyncio
import logging
import pymysql
from middleware.pymysqlpool.pymysqlpool import ConnectionPool
from web_tools.spider_log import SpiderLog
from web_tools.tools import Tools_user
from setting import Mysql, REDIS_HOST_LISTS
import redis


ip_lists = []
update = time.time()


class MyResponse(object):
    def __init__(self, url=None, headers=None, data=None, cookies=None, meta=None, text=None, content=None,
                 status_code=None, request_info=None, proxy=None):
        self.url = url  # 返回请求的的url
        self.data = data  # 返回请求用的data参数信息
        self.headers = headers  # 返回请求的header信息
        self.cookies = cookies  # 返回请求的cookies信息
        self.meta = meta  # 返回请求带过来的参数和值
        self.text = text  # 返回网站的响应体，包括html和json以及其他的任何数据
        self.content = content  # 返回的字节流
        self.status_code = status_code  # 返回响应状态吗
        self.request_info = request_info  # 返回请求体
        self.proxy = proxy  # 返回请求使用的代理


sem = asyncio.Semaphore(500)


class RedisDb(SpiderLog):
    def __init__(self):
        super().__init__()
        self.redis_host = REDIS_HOST_LISTS['host']
        self.redis_port = REDIS_HOST_LISTS['port']
        self.redis_pass = REDIS_HOST_LISTS['password']
        self.r = redis.Redis(host=self.redis_host, port=self.redis_port, password=self.redis_pass, db=7,
                             socket_timeout=None, connection_pool=None, charset='utf8', errors='strict',
                             decode_responses=True, unix_socket_path=None)


class Cluster(Tools_user, RedisDb):

    def __init__(self):
        Tools_user.__init__(self)
        RedisDb.__init__(self)
        self.logger = logging.getLogger(__name__)
        self.success_count = 0
        self.error_count = 0
        self.url = 'http://8.140.146.196:9090/qdb/get_proxy'
        self.charset_code = re.compile(r'charset=(.*?)"|charset=(.*?)>|charset="(.*?)"', re.S)
        # self.db = pymysql.connect(host=Mysql['MYSQL_HOST'], user=Mysql['MYSQL_USER'], password=Mysql['MYSQL_PASSWORD'],
        #                           port=Mysql['PORT'], db=Mysql['MYSQL_DBNAME'], charset='utf8', use_unicode=True)
        # self.cursor = self.db.cursor()
        # self.other_db = pymysql.connect(host=Mysql['MYSQL_HOST'], user=Mysql['MYSQL_USER'], password=Mysql['MYSQL_PASSWORD'],
        #                                 port=Mysql['PORT'], db=Mysql['MYSQL_DBNAME'], charset='utf8', use_unicode=True)
        # self.other_cursor = self.other_db.cursor()

        self.host = Mysql['MYSQL_HOST']
        self.port = Mysql['PORT']
        self.user = Mysql['MYSQL_USER']
        self.password = Mysql['MYSQL_PASSWORD']
        self.db = Mysql['MYSQL_DBNAME']
        # self.conn = None
        self.pool = self.create_pool()
        self.condition_re = re.compile('(.*?)\\(')
        self.params_re = re.compile('\\((.*?)\\)')

    def on_send_success(self, *args, **kwargs):
        self.success_count += 1

    def on_send_error(self, *args, **kwargs):
        self.error_count += 1

    def prints(self, item, is_replace=True):
        item_last = {}
        for k, v in item.items():
            if (v == None) or (v == 'None') or (v == ''):
                continue
            elif (('time' not in k) or ('Time' not in k) or ('updated' not in k) or ('date' not in k)) and (
                    isinstance(v, dict) == False):
                if is_replace:
                    item_last[k] = self.d_deal(v)
                else:
                    item_last[k] = v
            elif isinstance(v, dict):
                item_last[k] = str(v)
            elif k == 'body':
                item_last[k] = """{body}""".format(body=v)
            elif ('time' in k) or ('Time' in k) or ('updated' in k) or ('date' in k) or (k.endswith('T') == True):
                item_last[k] = v
        # print(json.dumps(item_last, indent=2, ensure_ascii=False))
        self.logger.info('\r\n' + json.dumps(item_last, indent=2, ensure_ascii=False))
        return item_last

    def send_where(self, dic_str):
        where = ''
        for key, value in dic_str.items():
            if len(value) > 1:
                for v in value:
                    where += '`' + key + '`="' + v + '" or '
            elif len(value) == 1:
                where += '`' + key + '`="' + str(value[0]) + '" and '
        # where = where.rstrip(' and ')
        where = where.rstrip(' or ')
        return where

    def create_pool(self):
        conn = ConnectionPool(
            pool_name='mypool',
            host=self.host,
            port=self.port,
            user=self.user,
            password=self.password,
            db=self.db,
            autocommit=False
        )
        return conn

    def execute(self, query, parameters=None, many=False):
        attempts = 3  # allow 3 attempts to execute the query
        while attempts > 0:
            conn = self.pool.borrow_connection()
            try:
                with conn.cursor() as cursor:
                    if many:
                        cursor.executemany(query, parameters)
                    else:
                        cursor.execute(query, parameters)
                    conn.commit()
                    if cursor.lastrowid:
                        return cursor.lastrowid
                    else:
                        return cursor.rowcount
            except pymysql.OperationalError as e:
                if e.args[0] in (2006, 2013):  # MySQL server has gone away
                    self.pool.close()
                    self.pool = self.create_pool()
                    attempts -= 1
                else:
                    raise
            except Exception as e:
                self.logger.error(f"Error while executing query: {e}")
                conn.rollback()
                attempts -= 1
                if attempts == 0:
                    raise Exception("Failed to execute query after 3 attempts")
            finally:
                self.pool.return_connection(conn)

                # if conn:
                #     conn.close()

    def insert(self, table, data, if_update=False):
        columns = ', '.join([f"`{i}`" for i in data.keys()])
        placeholders = ', '.join(['%s'] * len(data))
        query = f"INSERT IGNORE INTO `{table}` ({columns}) VALUES ({placeholders});"
        sql = query % tuple([f"'{i}'" if i else i for i in data.values()])
        if if_update:
            update = ', '.join([f"`{key}` = %s" for key in data.keys()])
            query = f"INSERT INTO {table} ({columns}) VALUES ({placeholders}) ON DUPLICATE KEY UPDATE {update}"
            sql = query % tuple([f"'{i}'" if i else i for i in data.values()] * 2)
        self.logger.info(sql)
        return self.execute(query, tuple(data.values()))

    def update(self, table, set_data, where=None):
        set_pairs = [f"`{column}`=%s" for column in set_data.keys()]
        query = f"UPDATE `{table}` SET {', '.join(set_pairs)}"
        parameters = tuple(set_data.values())
        if where:
            query += f" WHERE {where}"
        ssql = query % tuple([f"'{i}'" if i else i for i in parameters])
        self.logger.info(ssql)
        return self.execute(query, parameters)

    def delete(self, table, where=None):
        query = f"DELETE FROM `{table}`"
        if where:
            query += f" WHERE {where}"
        self.logger.info(query)
        return self.execute(query)

    def trucate(self, table):
        sql = f"""TRUNCATE `{table}`;"""
        return self.execute(sql)

    def get_condition(self, columns):
        condition_map = {'count': 'count', 'max': 'max', 'min': 'min', 'sum': 'sum', 'avg': 'avg',
                         'distinct': 'distinct'}
        condition = ''
        if isinstance(columns, list):
            columns = ', '.join([f"`{i}`" for i in columns])
        elif isinstance(columns, str):
            condition = self.deal_re(self.condition_re.search(columns))
            condition_exis = True if [True for i in condition_map.keys() if i.upper() in columns.upper()] else False
            if not condition_exis:
                columns = ', '.join(f'`{i.strip(" ")}`' for i in columns.split(','))
        return condition_map, condition, columns

    def select(self, table, columns='*', where=None, order_by=None, limit=None, offset=None):
        condition_map, condition, columns = self.get_condition(columns)
        query = f"SELECT {columns} FROM `{table}`"
        if where:
            query += f" WHERE {where}"
        if order_by:
            query += f" ORDER BY {order_by}"
        if limit:
            query += f" LIMIT {limit}"
        if offset:
            query += f" OFFSET {offset}"
        self.logger.info('查询字段：' + query)
        self.logger.info('===========================================================')
        with self.pool.cursor() as cursor:
            cursor.execute(query)
            data = cursor.fetchall()
            if self.judge_er(condition):
                condition_map = [i.upper() for i in condition_map.keys()]
            if f'{condition}' in condition_map:
                data = data[0].get(columns)
            return data

    def judge_er(self, str_data):
        if str_data.isupper():
            return True
        else:
            return False

    # def re_connet(self, if_other_db=False):
    #     if if_other_db:
    #         self.other_db = pymysql.connect(host=Mysql['MYSQL_HOST'], user=Mysql['MYSQL_USER'],
    #                                         password=Mysql['MYSQL_PASSWORD'], port=Mysql['PORT'],
    #                                         db=Mysql['MYSQL_DBNAME'], charset='utf8', use_unicode=True)
    #         self.other_cursor = self.other_db.cursor()
    #     else:
    #         self.db = pymysql.connect(host=Mysql['MYSQL_HOST'], user=Mysql['MYSQL_USER'],
    #                                   password=Mysql['MYSQL_PASSWORD'], port=Mysql['PORT'], db=Mysql['MYSQL_DBNAME'],
    #                                   charset='utf8', use_unicode=True)
    #         self.cursor = self.db.cursor()
    #
    # def trucate_sql(self, table, db_name=None, OTHER_INSERT=False):
    #     sql = """TRUNCATE `{db_name}`.`{table_name}`""".format(db_name=db_name, table_name=table)
    #     while 1:
    #         if OTHER_INSERT:
    #             try:
    #                 self.other_cursor.execute(sql)
    #                 self.other_db.commit()
    #                 break
    #             except pymysql.err.OperationalError:
    #                 self.re_connet(if_other_db=True)
    #         else:
    #             try:
    #                 self.cursor.execute(sql)
    #                 self.db.commit()
    #             except pymysql.err.OperationalError:
    #                 self.re_connet()
    #             break
    #
    # def insert(self, item, table, db_name=None, OTHER_INSERT=False, is_update=False, is_replace=True):
    #     item = self.prints(item, is_replace=is_replace)
    #     field_lists = []
    #     value_lists = []
    #     field_num = []
    #     for k, v in dict(item).items():
    #         if (v == None) or (v == 'None') or (v == ''):
    #             continue
    #         elif ('{' and '}') in v:
    #             field_lists.append("`" + str(k) + "`")
    #             value_lists.append(str(v))
    #         else:
    #             field_lists.append("`" + str(k) + "`")
    #             value_lists.append(str(v))
    #     [field_num.append('%s') for i in range(1, len(field_lists) + 1)]
    #     if db_name and is_update:
    #         new_values = []
    #         for i in value_lists:
    #             if i.isdigit():
    #                 new_values.append(i)
    #             else:
    #                 new_values.append("'" + i + "'")
    #         sql = """INSERT INTO `{db_name}`.`{table_name}`({fields}) VALUES({value_lists}) ON DUPLICATE KEY UPDATE {update_lists}""".format(
    #             db_name=db_name, table_name=table, fields=','.join(field_lists), value_lists=','.join(new_values),
    #             update_lists=','.join(self.update_item(item, is_insert=True, is_replace=is_replace)))
    #     elif db_name and is_update == False:
    #         sql = """INSERT IGNORE INTO `{db_name}`.`{table}` ({fields}) VALUES ({fields_num});""".format(
    #             db_name=db_name, table=table, fields=','.join(field_lists), fields_num=','.join(field_num))
    #     else:
    #         sql = """INSERT IGNORE INTO `{db_name}`.`{table}` ({fields}) VALUES ({fields_num});""".format(
    #             db_name=Mysql['MYSQL_DBNAME'], table=table, fields=','.join(field_lists),
    #             fields_num=','.join(field_num))
    #     while 1:
    #         if OTHER_INSERT:
    #             try:
    #                 if is_update:
    #                     self.other_cursor.execute(sql)
    #                     self.other_db.commit()
    #                 else:
    #                     self.other_cursor.execute(sql, tuple(value_lists))
    #                     self.other_db.commit()
    #                 break
    #             except pymysql.err.OperationalError:
    #                 self.re_connet(if_other_db=True)
    #         else:
    #             try:
    #                 if is_update:
    #                     self.cursor.execute(sql)
    #                     self.db.commit()
    #                 else:
    #                     self.cursor.execute(sql, tuple(value_lists))
    #                     self.db.commit()
    #                 break
    #             except pymysql.err.OperationalError:
    #                 self.re_connet()
    #     # print('===========================================================')
    #     self.logger.info('===========================================================')
    #
    # def select_data(self, field_lists=None, db_name=None, table=None, condition=None, where=0, num_id=0, min_id=0,
    #                 max_id=0, cond=None, OTHER_INSERT=False, if_dic=False):
    #     field_lists_last = []
    #     if field_lists:
    #         for i in field_lists:
    #             field_lists_last.append("`" + str(i) + "`")
    #     sq1_all = ''
    #     if (num_id == 0) and (where == 0):
    #         sq1_all = """SELECT {field_lists} FROM `{db}`.`{table}`;""".format(db=db_name,
    #                                                                            field_lists=','.join(field_lists_last),
    #                                                                            table=table)
    #     if cond != None:
    #         sq1_all = """SELECT {field_lists} FROM `{db}`.`{table}` {cond};""".format(db=db_name, field_lists=','.join(
    #             field_lists_last), table=table, cond=cond)
    #     if (num_id == 0) and (where != 0):
    #         sq1_all = """SELECT {field_lists} FROM `{db}`.`{table}` WHERE {where};""".format(db=db_name,
    #                                                                                          field_lists=','.join(
    #                                                                                              field_lists_last),
    #                                                                                          table=table, where=where)
    #     if num_id != 0:
    #         sq1_all = """SELECT {field_lists} FROM `{db}`.`{table}` WHERE `wid` = {id};""".format(db=db_name,
    #                                                                                               field_lists=','.join(
    #                                                                                                   field_lists_last),
    #                                                                                               table=table,
    #                                                                                               id=num_id)
    #     if (min_id == 0) and (max_id == 0):
    #         pass
    #     if (max_id != 0):
    #         sq1_all = """SELECT {field_lists} FROM `{db}`.`{table}` WHERE (`id` >= {min}) AND (`id` <= {max});""".format(
    #             db=db_name, field_lists=','.join(field_lists_last), table=table, min=min_id, max=max_id)
    #     if condition:
    #         sq1_all = """SELECT {condition} {field_lists} FROM `{db}`.`{table}`;""".format(condition=condition,
    #                                                                                        field_lists=','.join(
    #                                                                                            field_lists_last),
    #                                                                                        db=db_name, table=table)
    #     if condition and cond:
    #         sq1_all = """SELECT {condition} {field_lists} FROM `{db}`.`{table}` {cond};""".format(condition=condition,
    #                                                                                               field_lists=','.join(
    #                                                                                                   field_lists_last),
    #                                                                                               db=db_name,
    #                                                                                               table=table,
    #                                                                                               cond=cond)
    #     if condition and where:
    #         sq1_all = """SELECT {condition} {field_lists} FROM `{db}`.`{table}` WHERE {where};""".format(condition=condition,
    #                                                                                               field_lists=','.join(
    #                                                                                                   field_lists_last),
    #                                                                                               db=db_name,
    #                                                                                               table=table,
    #                                                                                               where=where)
    #     # print('\033[1;31;0m{tt}查询字段：\033[0m'.format(tt=str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))), sq1_all)
    #     self.logger.info('查询字段：' + sq1_all)
    #     self.logger.info('===========================================================')
    #     # print('===========================================================')
    #     while 1:
    #         if OTHER_INSERT:
    #             try:
    #                 self.other_cursor.execute(sq1_all)
    #                 self.other_db.commit()
    #                 data_all = self.other_cursor.fetchall()
    #                 dic_data_all = []
    #                 if if_dic:
    #                     for i in data_all:
    #                         dic_data = dict(zip(field_lists, i))
    #                         dic_data_all.append(dic_data)
    #                     return dic_data_all
    #                 return data_all
    #             except pymysql.err.OperationalError:
    #                 self.re_connet(if_other_db=True)
    #         else:
    #             try:
    #                 self.cursor.execute(sq1_all)
    #                 self.db.commit()
    #                 data_all = self.cursor.fetchall()
    #                 dic_data_all = []
    #                 if if_dic:
    #                     for i in data_all:
    #                         dic_data = dict(zip(field_lists, i))
    #                         dic_data_all.append(dic_data)
    #                     return dic_data_all
    #                 return data_all
    #             except pymysql.err.OperationalError:
    #                 self.re_connet()
    #
    # def delete_sql(self, db_name, table_name, where, OTHER_INSERT=False):
    #     sql = f"""delete from `{db_name}`.`{table_name}` where {where}"""
    #     self.logger.info('查询字段：' + sql)
    #     self.logger.info('===========================================================')
    #     while 1:
    #         if OTHER_INSERT:
    #             try:
    #                 self.other_cursor.execute(sql)
    #                 self.other_db.commit()
    #                 break
    #             except pymysql.err.OperationalError:
    #                 self.re_connet(if_other_db=True)
    #         else:
    #             try:
    #                 self.cursor.execute(sql)
    #                 self.db.commit()
    #                 break
    #             except pymysql.err.OperationalError:
    #                 self.re_connet()
    #
    # def update_item(self, item, is_insert=False, is_replace=True):
    #     field_lists_last = []
    #     for k, v in item.items():
    #         if ('time' in k) or ('Time' in k) or (k.endswith('T') == True):
    #             data = "`" + str(k) + "`" + "='{values}'".format(values=pymysql.converters.escape_string(str(v)))
    #         elif str(v).isdigit() and is_insert:
    #             data = "`" + str(k) + "`" + "={values}".format(values=v)
    #         elif (v == '') or (v == None):
    #             data = "`" + str(k) + "`" + "=NULL".format(values=v)
    #         else:
    #             if is_replace:
    #                 data = "`" + str(k) + "`" + "='{values}'".format(values=pymysql.converters.escape_string(str(self.d_deal(v))))
    #             else:
    #                 data = "`" + str(k) + "`" + "='{values}'".format(values=pymysql.converters.escape_string(str(v)))
    #         field_lists_last.append(data)
    #     # if is_insert == False:
    #     # print(json.dumps(field_lists_last, indent=2, ensure_ascii=False))
    #     # self.logger.info('\r\n'+json.dumps(field_lists_last, indent=2, ensure_ascii=False))
    #     return field_lists_last
    #
    # def update_data(self, item, db_name, table, where=0, OTHER_INSERT=False, is_replace=True):
    #     # print('\033[1;31;0m{tt}更新字段：\033[0m'.format(tt=str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))))
    #     # self.logger.info('更新字段：')
    #     item = self.update_item(item, is_replace=is_replace)
    #     update_sql = """UPDATE `{db}`.`{table_name}` SET {field_lists} WHERE {where}""".format(db=db_name,
    #                                                                                            table_name=table,
    #                                                                                            field_lists=','.join(
    #                                                                                                item), where=where)
    #     while 1:
    #         self.logger.info(update_sql)
    #         if OTHER_INSERT:
    #             try:
    #                 self.other_cursor.execute(update_sql)
    #                 self.other_db.commit()
    #                 break
    #             except pymysql.err.OperationalError:
    #                 self.re_connet(if_other_db=True)
    #         else:
    #             try:
    #                 self.cursor.execute(update_sql)
    #                 self.db.commit()
    #             except pymysql.err.OperationalError:
    #                 self.re_connet()
    #             break
    #         # print(update_sql)
    #         # self.logger.info('\r\n' + update_sql)

    async def data_deal(self, data):  # 一般数据处理
        if (data == None) or (data == ''):
            data_last = ''
            return data_last
        elif isinstance(data, dict):
            return json.loads(data)
        else:
            sin_list = ['\r', '\n', '\xa0', '\u3000', '\\u3000', '\t', ' ', '&nbsp;', '\\r', '\\n', ',,']
            for i in sin_list:
                data = str(data).replace(i, '')
            return data

    async def deal_json(self, response):
        ippool = json.loads(response)['http']
        ip_lists.append(ippool)

    async def asy_rand_choi_pool_response(self):  # 适用于aiohttp
        try:
            async with aiohttp.ClientSession() as session:
                response = await session.get(url=self.url)
                res = await response.read()
                return res.decode('utf-8')
        except Exception as e:
            self.logger.debug(str(e))
            return False

    async def asy_rand_choi_pool(self):
        global ip_lists
        global update
        if (len(ip_lists) == 0) or (time.time() - update >= 60):
            response = await self.asy_rand_choi_pool_response()
            while response == False:
                response = await self.asy_rand_choi_pool_response()
            try:
                await self.deal_json(response=response)
            except:
                while len(ip_lists) == 0:
                    try:
                        response = await self.asy_rand_choi_pool_response()
                        await self.deal_json(response=response)
                    except:
                        ip_lists = ip_lists
        if len(ip_lists) != 0:
            proxy = ip_lists.pop()
            return proxy

    async def deal_code(self, res):
        import chardet  # 字符集检测
        charset_code = chardet.detect(res[0:1])['encoding']
        # charset_code = self.deal_re(self.charset_code.search(str(res)))
        if charset_code:
            try:
                text = res.decode(charset_code)
                return text
            except (UnicodeDecodeError, TypeError, LookupError):
                text = await self.cycle_charset(res)
                return text
            except Exception as e:
                self.logger.error('Decoding error', exc_info=True)
        else:
            text = await self.cycle_charset(res)
            return text

    async def cycle_charset(self, res):  # 异常编码处理函数
        charset_code_list = ['utf-8', 'gbk', 'gb2312']
        for code in charset_code_list:
            try:
                text = res.decode(code)
                return text
            except UnicodeDecodeError:
                continue
            except Exception as e:
                self.logger.error('Decoding error again', exc_info=True)

    async def try_get_request(self, url, callback=None, headers=None, meta=None, timeout=10):
        async with sem:
            try:
                async with aiohttp.ClientSession(headers=headers, conn_timeout=timeout) as session:
                    async with session.get(url=url, headers=headers, proxy=await self.asy_rand_choi_pool(),
                                           timeout=timeout) as response:
                        res = await response.read()
                        if callback != None:
                            if ('img_' in callback.__name__):
                                response_last = MyResponse(url=url, headers=headers, cookies=response.cookies,
                                                           meta=meta, text='这是一张图片',
                                                           content=res, status_code=response.status)
                                return response_last
                        else:
                            text = await self.deal_code(res=res)
                            response_last = MyResponse(url=url, headers=headers, cookies=response.cookies, meta=meta,
                                                       text=text, content=res, status_code=response.status)
                            return response_last
            except Exception as e:
                return False

    async def get_request(self, url, callback=None, headers=None, meta=None, timeout=10):
        response = await self.try_get_request(url=url, callback=callback, headers=headers, meta=meta, timeout=timeout)
        while response == False:
            response = await self.try_get_request(url=url, callback=callback, headers=headers, meta=meta,
                                                  timeout=timeout)

        if (callback == None):
            return response
        else:
            await self.__getattribute__(callback.__name__)(response=response)

    async def try_post_request(self, url, headers=None, meta=None, timeout=10, data=None):
        async with sem:
            try:
                async with aiohttp.ClientSession(headers=headers, conn_timeout=timeout) as session:
                    if '127.0.0.1' in url:
                        async with session.post(url=url, headers=headers, data=data, timeout=timeout) as response:
                            res = await response.read()
                    else:
                        async with session.post(url=url, headers=headers, data=data,
                                                proxy=await self.asy_rand_choi_pool(), timeout=timeout) as response:
                            res = await response.read()
                    text = await self.deal_code(res=res)
                    response_last = MyResponse(url=url, headers=headers, data=data, cookies=response.cookies, meta=meta,
                                               text=text, content=res, status_code=response.status)
                    return response_last
            except:
                return False

    async def post_request(self, url, callback=None, headers=None, meta=None, timeout=10, data=None):
        response = await self.try_post_request(url=url, headers=headers, meta=meta, timeout=timeout, data=data)
        while response == False:
            response = await self.try_post_request(url=url, headers=headers, meta=meta, timeout=timeout, data=data)

        if (callback == None):
            return response
        else:
            await self.__getattribute__(callback.__name__)(response=response)

    def url_code(self, chara, encoding='utf-8'):
        from urllib import parse
        data = str(parse.quote(chara, encoding=encoding))
        return data

    def filters_value(self, dic_data):
        for i in dic_data:
            if i['status'] == 0:
                i['status'] = '缺少'
            elif i['status'] == 1:
                i['status'] = '多出'
            elif i['status'] == 2:
                i['status'] = '重合'
            else:
                i['status'] = '未知'
        return dic_data


if __name__ == '__main__':
    cl = Cluster()
    cl.trucate(table='rizhi_shixin_real_time_page')
    cl.trucate(table='rizhi_shixin_real_time')



import os
import sys
import time
import socket
import random
from pathlib import Path

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
sys.path.insert(0, BASE_DIR)


def re_name(str_data):
    new_name = ''.join([i.capitalize() for i in str_data.split('_')])
    return new_name


urls_py = """# -*- coding: utf-8 -*-
from application.{app_dir}.{app_name} import {app_class}

{app_name} = {app_class}()

url_list = [
    ['GET', '/{app_name}_index', {app_name}.index]
]
"""


def creat_urls(app_name):
    app_dir = app_name.capitalize()
    app_class = app_dir
    urls_model = urls_py.format(app_dir=app_dir, app_name=app_name, app_class=app_class)
    return urls_model


app_py = """# -*- coding: utf-8 -*-
from aiohttp import web
from middleware.connecter import Cluster


class {app_class}(Cluster):
    def __init__(self):
        super().__init__()

    async def index(self, request):
        return web.Response(text='Hello World!')
"""


def creat_app(app_name):
    app_class = app_name.capitalize()
    app_model = app_py.format(app_class=app_class)
    return app_model


def creat_file(path, app_name=None):
    init_file = open(f'{path}/__init__.py', 'w')
    init_file.close()
    with open(f'{path}/urls.py', 'wb') as u:
        url_model = creat_urls(app_name)
        u.write(url_model.encode('utf-8'))
    with open(f'{path}/{app_name}.py', 'wb') as a:
        app_model = creat_app(app_name)
        a.write(app_model.encode('utf-8'))
    return


def production(app_name):
    sys.argv.pop(0)
    current_path = os.getcwd()
    if len(sys.argv) != 0:
        current_path = current_path
    else:
        current_path = f'{os.getcwd()}/application/{app_name.capitalize()}'  # 应用路径

    flag = os.path.exists(current_path)
    if not flag:  # 不存在即创建
        os.makedirs(current_path)
        creat_file(path=current_path, app_name=app_name)
        print(f'{app_name.capitalize()}应用创建成功')
    elif flag:  # 如果存在，人工判断是否覆盖
        print(f'\033[1;31;0m名称为：{app_name.capitalize()}的应用已经存在\033[0m')
        while 1:
            judge = input('是否覆盖(y/n)?')
            if judge == 'y':
                creat_file(path=current_path, app_name=app_name)
                print('已覆盖')
                break
            if judge == 'n':
                pass
                break
            else:
                pass


if __name__ == '__main__':
    production('ceshi_app')



# -*- coding: utf-8 -*-
from aiohttp import web
from functools import wraps
from middleware.connecter import Cluster
from ldap3 import ALL, Connection, Server
from aiohttp_session import get_session
from decorator import decorator
import json
from authlib.jose import jwt
from authlib.jose.errors import ExpiredTokenError
import time
from datetime import datetime, timedelta


class InvalidUserOrPasswordException(Exception):
    def __init__(self):
        self.message = '没有此用户'


class Log_user(Cluster):
    def __init__(self):
        super().__init__()
        self._SERVER = Server('ldap.bl-ai.com', get_info=ALL)
        self._BASE_DN_USER = 'ou=users,dc=bailian,dc=ai'

    async def login_success(self, username: str, password: str):
        user = f"cn={username},{self._BASE_DN_USER}"
        conn = Connection(self._SERVER, user=user, password=password)
        if not conn.bind():
            raise InvalidUserOrPasswordException()
        return True

    # # 登录视图函数
    async def login(self, request):
        info = await request.text()
        data = json.loads(info)
        # data = await request.post()
        username = data['username']
        password = data['password']

        # 验证用户是否存在并密码是否正确
        if await self.login_success(username, password):
            # 设置过期时间为 30 分钟
            expires_in = timedelta(minutes=525600)

            # 生成当前时间和过期时间
            now = datetime.utcnow()
            expires_at = now + expires_in

            # 生成 Token
            # payload = {'sub': username, 'username': username, 'iat': int(time.time())}
            payload = {
                'sub': username,
                'username': username,
                'iat': now,
                'exp': expires_at,
            }

            token = jwt.encode({'alg': 'HS256', 'typ': 'JWT'}, payload, 'yuanshaohang').decode('utf-8')
            self.r.set(username, token)
            # 将 Token 返回给客户端
            return web.json_response({'code': 200, 'message': '登录成功！', 'token': token})
        else:
            return web.json_response({'error': 'Invalid username or password'})



# -*- coding: utf-8 -*-
import logging
import asyncio
import argparse
import aiohttp_cors
from aiohttp import web
from web_tools.spider_log import SpiderLog
from urls import urlpatterns
from web_tools.tools import get_ip
from middleware.JWTfilter import LoginAuth
from setting import is_auth_required, login_name


class Router(SpiderLog):
    def __init__(self, app_name):
        super().__init__()
        self.logger = logging.getLogger(__name__)
        self.app_name = app_name
        if is_auth_required:
            self.auth_required = LoginAuth().auth_required


    async def make_router(self, url_patterns):
        url_patterns_map = {}
        for url_list in url_patterns:
            app_name = ''
            for method_info in url_list:
                app_name = method_info[2].__qualname__.split('.')[0]
            url_patterns_map[app_name] = url_list
        return url_patterns_map

    async def init(self, loop):
        app_server = argparse.ArgumentParser(description="服务启动中心")
        app_server.add_argument(
            "-d", "--app_name", help="启动指定的app服务 例 python -d <app_name>", metavar=""
        )
        args = app_server.parse_args()
        app = web.Application(loop=loop)
        cors = aiohttp_cors.setup(app, defaults={
            "*": aiohttp_cors.ResourceOptions(
                allow_credentials=True,
                expose_headers="*",
                allow_headers="*",
            )
        })
        url_patterns_map = await self.make_router(url_patterns=urlpatterns)
        if args.app_name or self.app_name:
            url_list = url_patterns_map[args.app_name if args.app_name else self.app_name]
            for method_info in url_list:
                method = method_info[2]
                router_method = self.auth_required(method) if is_auth_required and method.__name__ not in login_name else method
                app.router.add_route(method_info[0], method_info[1], router_method)
        else:
            for app_name, url_list in url_patterns_map.items():
                for method_info in url_list:
                    method = method_info[2]
                    router_method = self.auth_required(method) if is_auth_required and method.__name__ not in login_name else method
                    app.router.add_route(method_info[0], method_info[1], router_method)

        for route in list(app.router.routes()):
            cors.add(route)
        await loop.create_server(app.make_handler(), '0.0.0.0', 8889)
        self.logger.info(
            f'''===================={args.app_name if args.app_name else self.app_name}服务启动成功 http://{ get_ip() }:{8889} =====================''')


def start_server(app_name=''):
    router = Router(app_name=app_name)
    loop = asyncio.get_event_loop()
    loop.run_until_complete(router.init(loop))
    loop.run_forever()


if __name__ == '__main__':
    router = Router('')
    loop = asyncio.get_event_loop()
    loop.run_until_complete(router.init(loop))
    loop.run_forever()



# -*-coding: utf-8-*-
# Author : Christopher Lee
# License: MIT License
# File   : test_container.py
# Date   : 2017-06-16 09-22
# Version: 0.1
# Description: description of this file.

import random
import threading
import logging

import time

from pymysqlpool.pool import *

logging.basicConfig(format='[%(asctime)s][%(name)s][%(module)s.%(lineno)d][%(levelname)s] %(message)s',
                    datefmt='%Y-%m-%d %H:%M:%S',
                    level=logging.DEBUG)

container = PoolContainer(10)


def test_add_new_items():
    for _ in range(100):
        try:
            container.add(random.randint(10, 100000))
        except PoolIsFullException:
            print('Full')


def test_get_return():
    test_add_new_items()

    for _ in range(100):
        item = container.get(wait_timeout=10)
        # print(item)
        print((container.pool_size, container.free_size), item)
        container.return_(item)


def worker(id_):
    print('[{}] try to get a free item'.format(id_))
    item = container.get(wait_timeout=60)
    print('[{}] get item: {}'.format(id_, item))
    time.sleep(random.randint(1, 10) / random.randint(10, 20))
    container.return_(item)


def test_with_multi_threads():
    test_add_new_items()
    threads = [threading.Thread(target=worker, args=(i,)) for i in range(1000)]
    for t in threads:
        t.start()

    for t in threads:
        t.join()


if __name__ == '__main__':
    test_add_new_items()
    # test_get_return()
    # test_with_multi_threads()



# -*-coding: utf-8-*-
# Author : Christopher Lee
# License: MIT License
# File   : container.py
# Date   : 2017-06-16 07-12
# Version: 0.1
# Description: pool container, thread-safe


import logging
import threading
from queue import Queue, Empty

__version__ = '0.1'
__author__ = 'Chris'

logger = logging.getLogger('pymysqlpool')

__all__ = ['PoolContainer', 'PoolIsEmptyException', 'PoolIsFullException']


class PoolIsFullException(Exception):
    pass


class PoolIsEmptyException(Exception):
    pass


class PoolContainer(object):
    """
    Pool container class: it's a pool manager with safe threading locks.
    Be aware of the dead lock!!!!!!!!!!!
    """

    def __init__(self, max_pool_size):
        self._pool_lock = threading.RLock()
        self._free_items = Queue()
        # self._pool_items = list()
        self._pool_items = set()
        self._max_pool_size = 0
        self.max_pool_size = max_pool_size

    def __repr__(self):
        return '<{0.__class__.__name__} {0.size})>'.format(self)

    def __iter__(self):
        with self._pool_lock:
            return iter(self._pool_items)

    def __contains__(self, item):
        with self._pool_lock:
            return item in self._pool_items

    def __len__(self):
        with self._pool_lock:
            return len(self._pool_items)

    def add(self, item):
        """Add a new item to the pool"""
        # Duplicate item will be ignored
        if item is None:
            return None

        if item in self:
            logger.debug(
                'Duplicate item found "{}", '
                'current size is "{}"'.format(item, self.size))
            return None

        if self.pool_size >= self.max_pool_size:
            raise PoolIsFullException()

        self._free_items.put_nowait(item)
        with self._pool_lock:
            # self._pool_items.append(item)
            self._pool_items.add(item)

        logger.debug(
            'Add item "{!r}",'
            ' current size is "{}"'.format(item, self.size))

    def return_(self, item):
        """Return a item to the pool. Note that the item to be returned should exist in this pool"""
        if item is None:
            return False

        if item not in self:
            logger.error(
                'Current pool dose not contain item: "{}"'.format(item))
            return False

        self._free_items.put_nowait(item)
        logger.debug('Return item "{!r}", current size is "{}"'.format(item, self.size))
        return True

    def get(self, block=True, wait_timeout=60):
        """Block until a free item is found in `wait_timeout` seconds.
        Otherwise, a `WaitTimeoutException` will be raised.

        If `wait_timeout` is None, it will block forever until a free item is found.
        """
        try:
            item = self._free_items.get(block, timeout=wait_timeout)
        except Empty:
            raise PoolIsEmptyException('Cannot find any available item')
        else:
            logger.debug('Get item "{}",'
                         ' current size is "{}"'.format(item, self.size))
            return item

    @property
    def size(self):
        # Return a tuple of the pool size in detail
        return '<max={}, current={}, free={}>'.format(self.max_pool_size, self.pool_size, self.free_size)

    @property
    def max_pool_size(self):
        return self._max_pool_size

    @max_pool_size.setter
    def max_pool_size(self, value):
        if value > self._max_pool_size:
            self._max_pool_size = value

    @property
    def pool_size(self):
        return len(self)

    @property
    def free_size(self):
        """Not reliable as described in document of the `queue` module"""
        return self._free_items.qsize()



__all__ = ['ConnectionPool']

_instances = {}


def ConnectionPool(*args, **kwargs):
    """Connection pool factory function, singleton instance factory.
    If you want a single connection pool, call this factory function.

    :param args: positional arguments passed to `MySQLConnectionPool`
    :param kwargs: dict arguments passed to `MySQLConnectionPool`
    :return: instance of class`MySQLConnectionPool`
    """
    from .connection import MySQLConnectionPool
    try:
        pool_name = args[0]
    except IndexError:
        pool_name = kwargs['pool_name']

    if pool_name not in _instances:
        _instances[pool_name] = MySQLConnectionPool(*args, **kwargs)
    pool = _instances[pool_name]
    assert isinstance(pool, MySQLConnectionPool)
    return pool



import re
import sys
import oss2
import html
import time
import json
import base64
import socket
import hashlib
import datetime
import dateparser
import dateutil.parser
from urllib import parse as pp
from dateutil.parser import parse
from importlib import import_module
from xml.sax.saxutils import unescape, escape
from setting import oss_config
from web_tools.file_tools.Stream_local import stream_type
from web_tools.file_tools.ocrutils_local import reco_url


class ImproperlyConfigured(Exception):
    """Django is somehow improperly configured"""
    pass


def include(arg, namespace=None):
    app_name = None
    if isinstance(arg, tuple):
        # Callable returning a namespace hint.
        try:
            urlconf_module, app_name = arg
        except ValueError:
            if namespace:
                raise ImproperlyConfigured(
                    'Cannot override the namespace for a dynamic module that '
                    'provides a namespace.'
                )
            raise ImproperlyConfigured(
                'Passing a %d-tuple to include() is not supported. Pass a '
                '2-tuple containing the list of patterns and app_name, and '
                'provide the namespace argument to include() instead.' % len(arg)
            )
    else:
        # No namespace hint - use manually provided namespace.
        urlconf_module = 'application.' + arg

    if isinstance(urlconf_module, str):
        urlconf_module = import_module(urlconf_module)
    patterns = getattr(urlconf_module, 'urlpatterns', urlconf_module)
    app_name = getattr(urlconf_module, 'app_name', app_name)
    if namespace and not app_name:
        raise ImproperlyConfigured(
            'Specifying a namespace in include() without providing an app_name '
            'is not supported. Set the app_name attribute in the included '
            'module, or pass a 2-tuple containing the list of patterns and '
            'app_name instead.',
        )
    namespace = namespace or app_name
    # Make sure the patterns can be iterated through (without this, some
    # testcases will break).
    if isinstance(patterns, (list, tuple)):
        for url_pattern in patterns:
            pattern = getattr(url_pattern, 'pattern', None)
    # return (urlconf_module, app_name, namespace)
    return urlconf_module


def get_ip():
    # 获取计算机名称
    hostname = socket.gethostname()
    # 获取本机IP
    ip = socket.gethostbyname(hostname)
    return ip


class Tools_user(object):

    def production_md5(self, str_data):  # 生成md5
        md5 = hashlib.md5(str_data.encode(encoding='UTF-8')).hexdigest()
        return md5

    def per_dic_plus(self, dic_data, key_list):
        data = ''
        for key in key_list:
            da = dic_data.get(key)
            if da:
                data = da
                break
        return data

    def d_deal(self, data):  # 一般数据处理
        if (data == None) or (data == ''):
            data_last = ''
            return data_last
        elif isinstance(data, dict):
            return json.loads(data)
        else:
            sin_list = ['\r', '\n', '\xa0', '\u3000', '\\u3000', '\t', ' ', '&nbsp;', '\\r', '\\n', ',,']
            for i in sin_list:
                data = str(data).replace(i, '')
            return data

    def now_time(self, is_date=False):  # 获取现在时间
        if is_date == False:
            now_time = str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))
            return now_time
        now_time = str(time.strftime("%Y-%m-%d", time.localtime()))
        return now_time

    def getYesterday(self, num=1):
        today = datetime.date.today()
        twoday = datetime.timedelta(days=num)
        yesterday = today - twoday
        return str(yesterday)

    def deal_re(self, demo, defult=None):  # 判断正则是否匹配到的是否为空
        if demo != None:
            data_tuple = demo.groups()
            lists = list(data_tuple)
            data = ''.join([i for i in lists if i != None])
            return data
        else:
            if defult:
                return defult
            return ''

    def get_time(self, str_data):  # 提取时间
        if str_data:
            data = self.deal_re(re.search(
                r"(\d{4}-\d{1,2}-\d{1,2}\s\d{1,2}:\d{1,2})|(\d{4}年\d{1,2}月\d{1,2}日)|(\d{4}-\d{1,2}-\d{1,2})|(\d{4}\.\d{1,2}\.\d{1,2})",
                str_data, re.S))
        else:
            data = ''
        return data

    def date_format(self, str_date):
        try:
            new_date = dateparser.parse(str_date).strftime('%Y-%m-%d %H:%M:%S')
            return new_date
        except AttributeError:
            try:
                new_date = parse(str_date)
                return str(new_date)
            except dateutil.parser.ParserError:
                return None
        except:
            return None

    def base64_encode(self, data):
        if isinstance(data, dict):
            data = json.dumps(data)
        if isinstance(data, int):
            data = str(data)
        data = base64.b64encode(data.encode('utf-8')).decode('utf-8')
        return data

    def base64_decode(self, data):
        data = base64.b64decode(data).decode('utf-8')
        return data

    def html_code(self, text, is_escape=False):
        data = text
        if is_escape:
            text = escape(text)
            if text == data:
                text = escape(text)
            else:
                return data
            return text
        else:
            text = unescape(text)
            if text == data.replace('amp;', '').replace('&gt;', '>'):
                text = html.unescape(text)
            else:
                return data
        return text

    def url_decode(self, chara, encoding='utf-8'):
        data = str(pp.unquote(chara, encoding=encoding))
        return data

    def get_nowtime(self):
        return str(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime()))

    async def get_file_length(self, file_bytes):
        content_length = len(file_bytes)
        mb = content_length / 1048576
        return int(mb)

    async def suc_rate(self, total_num, suc_num):
        rate = round(suc_num / total_num, 2)
        rate_baifen = f'{rate:.2%}'
        return rate_baifen

    async def get_bucket(self):
        access_key_id = oss_config['access_key_id']
        access_key_secret = oss_config['access_key_secret']
        endpoint = oss_config['endpoint'] if sys.platform != 'linux' else oss_config['endpoint_online']
        bucket_name = oss_config['bucket_name']
        return oss2.Bucket(oss2.Auth(access_key_id, access_key_secret), endpoint, bucket_name)

    async def oss_push_file(self, url, data, response=None, suffix='', custom=False, path=''):
        """
        :param url: 详情页链接
        :param data: 文件二进制数据流
        return: 对外能访问的图片URL
        """
        if len(data) < 10:
            return False
        oss_bucket = await self.get_bucket()
        stream = await stream_type(stream=data, response=response)
        if not stream and not custom:
            suffix_list = ['.doc', '.docx', '.xlr', '.xls', '.xlsx', '.pdf', '.txt', '.jpg', '.png', '.rar', '.zip']
            for i in suffix_list:
                if url.endswith(i):
                    suffix = i
            if not suffix.startswith('.'):
                suffix = '.' + suffix
        elif stream and not custom:
            suffix = '.' + stream
        else:
            if not suffix.startswith('.'):
                suffix = '.' + suffix
        if suffix:
            url_md5 = f'{path}{hashlib.sha1(url.encode()).hexdigest() + suffix}'
            oss_bucket.put_object(url_md5, data)
            oss_url = f'https://bid.snapshot.qudaobao.com.cn/{url_md5}'
            return oss_url

    async def ocr_result(self, file_bytes, key, response=None, host=None, is_update='2'):
        if len(file_bytes) > 10:
            stream = await stream_type(stream=file_bytes, response=response)
            result = []
            # if stream == 'pdf':
            #     result = await self.pdf2text(file_bytes)
            #     if not result:
            #         result = await reco_url(file_bytes, stream, key)
            # elif stream == 'jpg' or stream == 'png' or stream == 'doc' or stream == 'docx':
            #     result = await reco_url(file_bytes, stream, key, host=host)
            if stream == 'pdf' or stream == 'jpg' or stream == 'png' or stream == 'doc' or stream == 'docx':
                result = await reco_url(file_bytes, stream, key, host=host, is_update=is_update)
            return result
        else:
            return []

    async def get_small_file(self, file_bytes):
        fsize = len(file_bytes)
        print(fsize)
        if fsize <= 50 * 1024:
            return True


if __name__ == '__main__':
    # a = include('Time_controller.urls')
    # print(a.url_list)
    tool = Tools_user()
    a = tool.getYesterday()
    print(a)



# -*-coding: utf-8-*-
# Author : Christopher Lee
# License: Apache License
# File   : test_example.py
# Date   : 2017-06-18 01-23
# Version: 0.0.1
# Description: simple test.


import logging
import string
import threading

import pandas as pd
import random

from pymysqlpool import ConnectionPool

config = {
    'pool_name': 'test',
    'host': 'localhost',
    'port': 3306,
    'user': 'root',
    'password': 'chris',
    'database': 'test',
    'pool_resize_boundary': 50,
    'enable_auto_resize': True,
    # 'max_pool_size': 10
}

logging.basicConfig(format='[%(asctime)s][%(name)s][%(module)s.%(lineno)d][%(levelname)s] %(message)s',
                    datefmt='%Y-%m-%d %H:%M:%S',
                    level=logging.DEBUG)


def connection_pool():
    # Return a connection pool instance
    pool = ConnectionPool(**config)
    # pool.connect()
    return pool


def test_pool_cursor(cursor_obj=None):
    cursor_obj = cursor_obj or connection_pool().cursor()
    with cursor_obj as cursor:
        print('Truncate table user')
        cursor.execute('TRUNCATE user')

        print('Insert one record')
        result = cursor.execute('INSERT INTO user (name, age) VALUES (%s, %s)', ('Jerry', 20))
        print(result, cursor.lastrowid)

        print('Insert multiple records')
        users = [(name, age) for name in ['Jacky', 'Mary', 'Micheal'] for age in range(10, 15)]
        result = cursor.executemany('INSERT INTO user (name, age) VALUES (%s, %s)', users)
        print(result)

        print('View items in table user')
        cursor.execute('SELECT * FROM user')
        for user in cursor:
            print(user)

        print('Update the name of one user in the table')
        cursor.execute('UPDATE user SET name="Chris", age=29 WHERE id = 16')
        cursor.execute('SELECT * FROM user ORDER BY id DESC LIMIT 1')
        print(cursor.fetchone())

        print('Delete the last record')
        cursor.execute('DELETE FROM user WHERE id = 16')


def test_pool_connection():
    with connection_pool().connection(autocommit=True) as conn:
        test_pool_cursor(conn.cursor())


def test_with_pandas():
    with connection_pool().connection() as conn:
        df = pd.read_sql('SELECT * FROM user', conn)
        print(df)


def delete_users():
    with connection_pool().cursor() as cursor:
        cursor.execute('TRUNCATE user')


def add_users(users, conn):
    def execute(c):
        c.cursor().executemany('INSERT INTO user (name, age) VALUES (%s, %s)', users)
        c.commit()

    if conn:
        execute(conn)
        return
    with connection_pool().connection() as conn:
        execute(conn)


def add_user(user, conn=None):
    def execute(c):
        c.cursor().execute('INSERT INTO user (name, age) VALUES (%s, %s)', user)
        c.commit()

    if conn:
        execute(conn)
        return
    with connection_pool().connection() as conn:
        execute(conn)


def list_users():
    with connection_pool().cursor() as cursor:
        cursor.execute('SELECT * FROM user ORDER BY id DESC LIMIT 5')
        print('...')
        for x in sorted(cursor, key=lambda d: d['id']):
            print(x)


def random_user():
    name = "".join(random.sample(string.ascii_lowercase, random.randint(4, 10))).capitalize()
    age = random.randint(10, 40)
    return name, age


def worker(id_, batch_size=1, explicit_conn=True):
    print('[{}] Worker started...'.format(id_))

    def do(conn=None):
        for _ in range(batch_size):
            add_user(random_user(), conn)

    if not explicit_conn:
        do()
        return

    with connection_pool().connection() as c:
        do(c)

    print('[{}] Worker finished...'.format(id_))


def bulk_worker(id_, batch_size=1, explicit_conn=True):
    print('[{}] Bulk worker started...'.format(id_))

    def do(conn=None):
        add_users([random_user() for _ in range(batch_size)], conn)
        time.sleep(3)

    if not explicit_conn:
        do()
        return

    with connection_pool().connection() as c:
        do(c)

    print('[{}] Worker finished...'.format(id_))


def test_with_single_thread(batch_number, batch_size, explicit_conn=False, bulk_insert=False):
    delete_users()
    wk = worker if not bulk_insert else bulk_worker
    for i in range(batch_number):
        wk(i, batch_size, explicit_conn)
    list_users()


def test_with_multi_threads(batch_number=1, batch_size=1000, explicit_conn=False, bulk_insert=False):
    delete_users()

    wk = worker if not bulk_insert else bulk_worker

    threads = []
    for i in range(batch_number):
        t = threading.Thread(target=wk, args=(i, batch_size, explicit_conn))
        threads.append(t)
        t.start()

    [t.join() for t in threads]
    list_users()


if __name__ == '__main__':
    import time

    start = time.perf_counter()
    test_pool_cursor()
    test_pool_connection()

    test_with_pandas()
    test_with_multi_threads(20, 10, True, bulk_insert=True)
    test_with_single_thread(1, 10, True, bulk_insert=True)
    elapsed = time.perf_counter() - start
    print('Elapsed time is: "{}"'.format(elapsed))



# import requests
# import json
#
# url = 'http://bailian-aliyun-crawler9.bl-ai.com:9999/weihuweb/login'
# data = {
#     'username': 'yuanshaohang',
#     'password': 'yhHoRatHtG8'
# }
#
# response = requests.post(url=url, json=data)
# print(response.cookies.get_dict())
# print(response.text)


# from aiohttp import web
# import time
# from authlib.jose import jwt
#
#
# async def login(request):
#     data = await request.post()
#     username = data['username']
#     password = data['password']
#
#     # 验证用户是否存在并密码是否正确
#     user = await db.get_user(username)
#     if user and check_password(user['password'], password):
#         # 生成 Token
#         payload = {'sub': user['id'], 'name': user['name'], 'iat': int(time.time())}
#         token = jwt.encode({'alg': 'HS256', 'typ': 'JWT'}, payload, 'secret')
#
#         # 将 Token 返回给客户端
#         return web.json_response({'token': token})
#     else:
#         return web.json_response({'error': 'Invalid username or password'})



# -*- coding: utf-8 -*-
from aiohttp import web
from middleware.connecter import Cluster


class First_app(Cluster):
    def __init__(self):
        super().__init__()

    async def get_result(self, fun_name, spider_name, spider_id):
        return {"code": "200", "msg": 'Successful!', 'data': [fun_name, spider_name, spider_id]}

    async def request_info(self, request):
        try:
            spider_name = request.rel_url.query.get('spider_name')
            spider_id = request.rel_url.query.get('spider_id')
            a = self.production_md5(spider_name)
            print(spider_name, spider_id, a)
            # spider_name = request.match_info.get('spider_name')
            # spider_id = request.match_info.get('spider_id')
            if spider_name:
                result = await self.get_result('request_info', spider_name, spider_id)
                print('返回值：' + str(result))
                print('获取数据成功')
                print('完成')
                return web.json_response(result)
        except:
            import traceback
            traceback.print_exc()
            return web.json_response({"code": "500", "msg": 'System anomaly'})

    async def post_info(self, request):
        try:
            spider_name = request.rel_url.query.get('spider_name')
            spider_id = request.rel_url.query.get('spider_id')
            print(spider_name, spider_id)
            # spider_name = request.match_info.get('spider_name')
            # spider_id = request.match_info.get('spider_id')
            if spider_name:
                result = await self.get_result('post_info', spider_name, spider_id)
                print('返回值：' + str(result))
                print('获取数据成功')
                print('完成')
                return web.json_response(result)
        except:
            import traceback
            traceback.print_exc()
            return web.json_response({"code": "500", "msg": 'System anomaly'})



# -*- coding: utf-8 -*-
# @Author: yuanshaohang
# @Date: 2023-03-24 16:33:05
# @Version: 1.0.0
# @Description: 创建pacer项目工程

import os
import sys
sys.path.append(os.path.dirname(os.path.abspath(__file__)))
import argparse
import shutil
from web_tools.builder import creat_file

def main():
    parser = argparse.ArgumentParser(description='Command parameters related to creating a pacer project project')
    parser.add_argument('-p', '--projectName', help='Name of the project to be created', required=True)
    parser.add_argument('-a', '--appName', help='Name of the prepared application', required=False)
    parser.add_argument('-t', '--projectPath', help='Prepare the path for creating the project', required=False)
    args = vars(parser.parse_args())

    projectName = args['projectName']
    appName = args['appName']
    projectPath = args['projectPath']


    # print(f"projectPath: {projectPath}")


    def ignore_txt_files(dirname, filenames):
        return [filename for filename in filenames if filename.endswith('.txt') or filename == 'pacer.py']


    project_path = os.path.dirname(os.path.abspath(__file__))
    # print(f'项目路径：{project_path}')

    if projectName:
        print(f"projectName: {projectName}")
        print(f'当前目录：{os.getcwd()}')
        craete_path = os.path.join(os.getcwd(), projectName) if not projectPath else project_path
        print(f'创建路径：{craete_path}')
        shutil.copytree(project_path, craete_path, ignore=ignore_txt_files, ignore_dangling_symlinks=True)
        if appName:
            app_path = f'{craete_path}/application/{appName.capitalize()}'
            os.makedirs(app_path)
            creat_file(path=app_path, app_name=appName)
            print(f'{appName.capitalize()}应用创建成功')


if __name__ == '__main__':
    main()